| Title: | 'Rcpp' Integration for 'CGAL' |
|---|---|
| Description: | Creates a header only package to link to the 'CGAL' (Computational Geometry Algorithms Library) header files in 'Rcpp'. There are a variety of potential uses for the software such as Hilbert sorting, K-D Tree nearest neighbors, and convex hull algorithms. For more information about how to use the header files, see the 'CGAL' documentation at <https://www.cgal.org>. Currently downloads version 6.1 of the 'CGAL' header files. |
| Authors: | Eric Dunipace [aut, cre] (ORCID: <https://orcid.org/0000-0001-8909-213X>), Tyler Morgan-Wall [ctb], The CGAL Project [cph] |
| Maintainer: | Eric Dunipace <[email protected]> |
| License: | GPL-3 |
| Version: | 6.1 |
| Built: | 2026-06-05 08:09:47 UTC |
| Source: | https://github.com/ericdunipace/rcppcgal |
Creates a header only package to link to the 'CGAL' (Computational Geometry Algorithms Library) header files in 'Rcpp'. There are a variety of potential uses for the software such as Hilbert sorting, K-D Tree nearest neighbors, and convex hull algorithms. For more information about how to use the header files, see the 'CGAL' documentation at https://www.cgal.org. Currently downloads version 6.1 of the 'CGAL' header files.
Maintainer: Eric Dunipace [email protected] (ORCID)
Other contributors:
Tyler Morgan-Wall [email protected] [contributor]
The CGAL Project [copyright holder]
The CGAL Project. (2023). CGAL User and Reference Manual. Retrieved from https://doc.cgal.org/latest/Manual/index.html
Useful links:
Report bugs at https://github.com/ericdunipace/RcppCGAL/issues
Check if CGAL header files exist in RcppCGAL package
cgal_is_installed()cgal_is_installed()
This function will perform a very simple check to see if the CGAL folder exists in the include directory and that it is non-empty. If the folder exists and is non-empty, the function returns TRUE; otherwise the function returns FALSE.
logical value
cgal_is_installed()cgal_is_installed()
Return CGAL version
cgal_version()cgal_version()
prints the CGAL version of the package
cgal_version()cgal_version()
This package will set the CGAL_DIR environmental variable if you don't know how. Then you can re-install the RcppCGAL package and the installation should use your preferred source of the CGAL library. Note the cleaner functions will run automatically and replace the calls to std::err and exit in the C code. They have been tested on CGAL 5.6 so are not guaranteed to work with other versions of the CGAL headers.
set_cgal(path)set_cgal(path)
path |
character vector. either a URL or system path |
Invisibley returns TRUE if the CGAL_DIR variable was successfully set or or FALSE if it was not.
## Not run: set_cgal("path/to/include/CGAL") ## End(Not run)## Not run: set_cgal("path/to/include/CGAL") ## End(Not run)
This package will remove the CGAL_DIR environmental variable.
unset_cgal(...)unset_cgal(...)
... |
Not used at this time |
Invisibley returns TRUE if the CGAL_DIR variable was successfully removed or or FALSE if it was not.
## Not run: unset_cgal() ## End(Not run)## Not run: unset_cgal() ## End(Not run)